@@ -207,7 +207,7 @@ static Glib::ustring convert_filepath_to_uri(const std::string& filepath)
 
 static void cleanup()
 {
-  Glom::ConnectionPool* connection_pool = Glom::ConnectionPool::get_instance();
+  auto connection_pool = Glom::ConnectionPool::get_instance();
 
   const auto stopped = connection_pool->cleanup( sigc::ptr_fun(&on_cleanup_progress) );
   g_assert(stopped);
@@ -372,7 +372,7 @@ int main(int argc, char* argv[])
 
   g_assert(document.get_is_example_file());;
 
-  Glom::ConnectionPool* connection_pool = Glom::ConnectionPool::get_instance();
+  auto connection_pool = Glom::ConnectionPool::get_instance();
 
   //Save a copy, specifying the path to file in a directory:
   filepath_dir = 
@@ -411,11 +411,11 @@ int main(int argc, char* argv[])
 
 #if GLOM_ENABLE_MYSQL
     if(group.m_arg_use_mysql)
-      document.set_hosting_mode(Glom::Document::HOSTING_MODE_MYSQL_SELF);
+      document.set_hosting_mode(Glom::Document::HostingMode::MYSQL_SELF);
     else
 #endif //GLOM_ENABLE_MYSQL
     {
-      document.set_hosting_mode(Glom::Document::HOSTING_MODE_POSTGRES_SELF);
+      document.set_hosting_mode(Glom::Document::HostingMode::POSTGRES_SELF);
     }
   }
   else
@@ -424,11 +424,11 @@ int main(int argc, char* argv[])
 
 #if GLOM_ENABLE_MYSQL
     if(group.m_arg_use_mysql)
-      document.set_hosting_mode(Glom::Document::HOSTING_MODE_MYSQL_CENTRAL);
+      document.set_hosting_mode(Glom::Document::HostingMode::MYSQL_CENTRAL);
     else
 #endif //GLOM_ENABLE_MYSQL
     {
-      document.set_hosting_mode(Glom::Document::HOSTING_MODE_POSTGRES_CENTRAL);
+      document.set_hosting_mode(Glom::Document::HostingMode::POSTGRES_CENTRAL);
     }
   }
    
@@ -468,8 +468,8 @@ int main(int argc, char* argv[])
     connection_pool->set_user(group.m_arg_server_username);
     connection_pool->set_password(password); //TODO: Take this from stdin instead.
     
-    Glom::ConnectionPool::Backend* backend = connection_pool->get_backend();
-    Glom::ConnectionPoolBackends::PostgresCentralHosted* central = 
+    auto backend = connection_pool->get_backend();
+    auto central = 
       dynamic_cast<Glom::ConnectionPoolBackends::PostgresCentralHosted*>(backend);
     g_assert(central);
 
@@ -499,17 +499,17 @@ int main(int argc, char* argv[])
   //Startup. For instance, create the self-hosting files if necessary:
   const Glom::ConnectionPool::InitErrors initialized_errors =
     connection_pool->initialize( sigc::ptr_fun(&on_initialize_progress) );
-  g_assert(initialized_errors == Glom::ConnectionPool::Backend::INITERROR_NONE);
+  g_assert(initialized_errors == Glom::ConnectionPool::Backend::InitErrors::NONE);
 
   //Start self-hosting:
   //TODO: Let this happen automatically on first connection?
   const auto started = connection_pool->startup( sigc::ptr_fun(&on_startup_progress) );
-  if(started != Glom::ConnectionPool::Backend::STARTUPERROR_NONE)
+  if(started != Glom::ConnectionPool::Backend::StartupErrors::NONE)
   {
-    std::cerr << G_STRFUNC << ": connection_pool->startup(): result=" << started << std::endl;
+    std::cerr << G_STRFUNC << ": connection_pool->startup(): result=" << Glom::Utils::to_utype(started) << std::endl;
     cleanup();
   }
-  g_assert(started == Glom::ConnectionPool::Backend::STARTUPERROR_NONE);
+  g_assert(started == Glom::ConnectionPool::Backend::StartupErrors::NONE);
 
   const auto recreated = Glom::DbUtils::recreate_database_from_document(&document, &on_recreate_progress);
   if(!recreated)
