@@ -51,48 +51,26 @@
 namespace Glom
 {
 
-template<class T_Element>
-class predicate_UsesRelationshipHasRelationships
+template
+<typename T_Container>
+auto find_if_uses_relationship_has_relationship(T_Container& container, const std::shared_ptr<const UsesRelationship> uses_relationship_name, bool first_level_only = false) -> decltype(container.begin())
 {
-public:
-  predicate_UsesRelationshipHasRelationships(const Glib::ustring& relationship_name, const Glib::ustring& related_relationship_name = Glib::ustring())
-  : m_relationship_name(relationship_name),
-    m_related_relationship_name(related_relationship_name)
-  {
-  }
+  const Glib::ustring relationship_name(uses_relationship_name->get_relationship_name());
+  Glib::ustring related_relationship_name(uses_relationship_name->get_related_relationship_name());
 
-  predicate_UsesRelationshipHasRelationships(const std::shared_ptr<const UsesRelationship> uses_relationship_name, bool first_level_only = false)
-  : m_relationship_name(uses_relationship_name->get_relationship_name()),
-    m_related_relationship_name(uses_relationship_name->get_related_relationship_name())
-  {
-    //If first_level_only, search for relationships that have the same top-level relationship, but have no related relationship.
-    if(first_level_only)
-      m_related_relationship_name = Glib::ustring();
-  }
+  //If first_level_only, search for relationships that have the same top-level relationship, but have no related relationship.
+  if(first_level_only)
+    related_relationship_name = Glib::ustring();
 
-  virtual ~predicate_UsesRelationshipHasRelationships()
-  {
-  }
-
-  bool operator() (const T_Element& element)
-  {
-    return (element.get_relationship_name() == m_relationship_name) && (element.get_related_relationship_name() == m_related_relationship_name);
-  }
-
-  bool operator() (const std::shared_ptr<T_Element>& element)
-  {
-    return (element->get_relationship_name() == m_relationship_name) && (element->get_related_relationship_name() == m_related_relationship_name);
-  }
-
-  bool operator() (const std::shared_ptr<const T_Element>& element)
-  {
-    return (element->get_relationship_name() == m_relationship_name) && (element->get_related_relationship_name() == m_related_relationship_name);
-  }
-
-private:
-  Glib::ustring m_relationship_name, m_related_relationship_name;
-};
+  return std::find_if(container.begin(), container.end(),
+    [&relationship_name, &related_relationship_name](const typename T_Container::value_type& element)
+    {
+      //Assume that element is a shared_ptr<>.
 
+      return (element->get_relationship_name() == relationship_name) && (element->get_related_relationship_name() == related_relationship_name);
+    }
+  );
+}
 
 Glib::ustring Utils::trim_whitespace(const Glib::ustring& text)
 {
@@ -178,7 +156,7 @@ Glib::ustring Utils::string_replace(const Glib::ustring& src, const Glib::ustrin
   size_t src_index_section_start = 0;
   while(src_index < src_length)
   {
-    const bool found = (src.find(search_for.c_str(), src_index) == src_index);
+    const bool found = (src.find(search_for, src_index) == src_index);
     if(found)
     {
       result += src.substr(src_index_section_start, src_index - src_index_section_start);
@@ -263,7 +241,7 @@ static void add_to_relationships_list(type_list_relationships& list_relationship
     return;
 
   //If this is a related relationship, add the first-level relationship too, so that the related relationship can be defined in terms of it:
-  type_list_relationships::const_iterator iterFind = std::find_if(list_relationships.begin(), list_relationships.end(), predicate_UsesRelationshipHasRelationships<UsesRelationship>(layout_item, true /* top_level_only */) );
+  type_list_relationships::const_iterator iterFind = find_if_uses_relationship_has_relationship(list_relationships, layout_item, true /* top_level_only */);
   if(iterFind == list_relationships.end()) //If the table is not yet in the list:
   {
     std::shared_ptr<UsesRelationship> uses_rel = std::make_shared<UsesRelationship>();
@@ -272,7 +250,7 @@ static void add_to_relationships_list(type_list_relationships& list_relationship
   }
 
   //Add the relationship to the list:
-  iterFind = std::find_if(list_relationships.begin(), list_relationships.end(), predicate_UsesRelationshipHasRelationships<UsesRelationship>(layout_item) );
+  iterFind = find_if_uses_relationship_has_relationship(list_relationships, layout_item);
   if(iterFind == list_relationships.end()) //If the table is not yet in the list:
   {
     std::shared_ptr<UsesRelationship> uses_rel = std::make_shared<UsesRelationship>();
@@ -373,7 +351,7 @@ void Utils::build_sql_select_add_fields_to_get(const Glib::RefPtr<Gnome::Gda::Sq
     const Glib::ustring parent = layout_item->get_sql_table_or_join_alias_name(table_name);
 
     //TODO: Use std::dynamic_pointer_cast?
-    const LayoutItem_FieldSummary* fieldsummary = dynamic_cast<const LayoutItem_FieldSummary*>(layout_item.get());
+    const auto fieldsummary = dynamic_cast<const LayoutItem_FieldSummary*>(layout_item.get());
     if(fieldsummary)
     {
       const Gnome::Gda::SqlBuilder::Id id_function = builder->add_function(
@@ -758,7 +736,7 @@ Glib::ustring Utils::create_local_image_uri(const Gnome::Gda::Value& value)
       result = ("/tmp/glom_report_image_" + Glib::ustring(pchExtraNum) + ".png");
       ++m_temp_image_uri_number;
 
-      std::fstream the_stream(result.c_str(), std::ios_base::out | std::ios_base::trunc | std::ios_base::binary);
+      std::fstream the_stream(result, std::ios_base::out | std::ios_base::trunc | std::ios_base::binary);
       if(the_stream)
       {
         the_stream.write((char*)pData, size);
@@ -1145,7 +1123,7 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
     Glib::ustring strClausePart;
 
     bool use_this_field = true;
-    if(field->get_glom_type() != Field::TYPE_TEXT)
+    if(field->get_glom_type() != Field::glom_field_type::TEXT)
     {
       use_this_field = false;
     }
@@ -1510,7 +1488,8 @@ LayoutGroup::type_list_const_items Utils::get_layout_items_plus_primary_key(cons
   pk_layout_item->set_hidden();
   pk_layout_item->set_full_field_details(field_primary_key);
   
-  const LayoutGroup::type_list_const_items::const_iterator iterFind = std::find_if(items.begin(), items.end(), predicate_LayoutItem_Field_IsSameField<LayoutItem_Field, LayoutItem>(pk_layout_item));
+  const LayoutGroup::type_list_const_items::const_iterator iterFind =
+    find_if_layout_item_field_is_same_field(items, pk_layout_item);
   if(iterFind != items.end())
     return items; //It is already in the list:
 
@@ -1539,7 +1518,8 @@ LayoutGroup::type_list_items Utils::get_layout_items_plus_primary_key(const Layo
   pk_layout_item->set_hidden();
   pk_layout_item->set_full_field_details(field_primary_key);
   
-  const LayoutGroup::type_list_items::const_iterator iterFind = std::find_if(items.begin(), items.end(), predicate_LayoutItem_Field_IsSameField<LayoutItem_Field, LayoutItem>(pk_layout_item));
+  const LayoutGroup::type_list_items::const_iterator iterFind = 
+    find_if_layout_item_field_is_same_field(items, pk_layout_item);
   if(iterFind != items.end())
     return items; //It is already in the list:
 
